@@ -15,9 +15,9 @@ public:
   static vtkFiltersParallelFlowPathsObjectFactory * New();
   vtkTypeMacro(vtkFiltersParallelFlowPathsObjectFactory, vtkObjectFactory);
 
-  const char * GetDescription() override { return "vtkFiltersParallelFlowPaths factory overrides."; }
+  const char * GetDescription() VTK_FUTURE_CONST override { return "vtkFiltersParallelFlowPaths factory overrides."; }
 
-  const char * GetVTKSourceVersion() override;
+  const char * GetVTKSourceVersion() VTK_FUTURE_CONST override;
 
   void PrintSelf(ostream &os, vtkIndent indent) override;
 
