@@ -33,6 +33,7 @@
 #  define VTKRENDERINGLICOPENGL2_DEPRECATED_NO_EXPORT VTKRENDERINGLICOPENGL2_NO_EXPORT VTKRENDERINGLICOPENGL2_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef VTKRENDERINGLICOPENGL2_NO_DEPRECATED
 #    define VTKRENDERINGLICOPENGL2_NO_DEPRECATED
@@ -44,6 +45,7 @@
 /* Include ABI Namespace */
 #include "vtkABINamespace.h"
 /* AutoInit dependencies. */
+#include "vtkRenderingCoreModule.h"
 #include "vtkRenderingOpenGL2Module.h"
 
 
