@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   Visualization Toolkit
-  Module:    vtkXOpenGLRenderWindow.h
-
-  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
-  All rights reserved.
-  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * @class   vtkXOpenGLRenderWindow
  * @brief   OpenGL rendering window
@@ -27,14 +15,17 @@
 
 #include "vtkOpenGLRenderWindow.h"
 #include "vtkRenderingOpenGL2Module.h" // For export macro
+#include "vtkWrappingHints.h"          // For VTK_MARSHALAUTO
 #include <X11/Xlib.h>                  // Needed for X types used in the public interface
 #include <stack>                       // for ivar
 
+VTK_ABI_NAMESPACE_BEGIN
 class vtkIdList;
 class vtkXOpenGLRenderWindowInternal;
 struct vtkXVisualInfo;
 
-class VTKRENDERINGOPENGL2_EXPORT vtkXOpenGLRenderWindow : public vtkOpenGLRenderWindow
+class VTKRENDERINGOPENGL2_EXPORT VTK_MARSHALAUTO vtkXOpenGLRenderWindow
+  : public vtkOpenGLRenderWindow
 {
 public:
   static vtkXOpenGLRenderWindow* New();
@@ -90,23 +81,21 @@ public:
   virtual void PrefFullScreen();
 
   /**
-   * Set the size (width and height) of the rendering window in
-   * screen coordinates (in pixels). This resizes the operating
-   * system's view/window and redraws it.
+   * Set the size (width and height in pixels) of the rendering window.
+   * If this is a toplevel window with borders, then the request for a
+   * new size is redirected to the window manager. If the window manager
+   * chooses a different size for the window, the size it chooses will
+   * take effect at the next render, otherwise the size change will take
+   * effect immediately. In the rare case that the window manager does
+   * does not respond at all (buggy/frozen window manager), the SetSize()
+   * method will wait for the response for two seconds before returning.
    *
-   * If the size has changed, this method will fire
-   * vtkCommand::WindowResizeEvent.
+   * If the size has changed, a vtkCommand::WindowResizeEvent will fire.
    */
   void SetSize(int width, int height) override;
   void SetSize(int a[2]) override { this->SetSize(a[0], a[1]); }
 
-  /**
-   * Specify the size of the rendering window in pixels but do not resize
-   * the XWindow. Useful when resizing is done interactively.
-   */
-  void SetSizeNoXResize(int, int);
-
-  //@{
+  ///@{
   /**
    * Get the X properties of an ideal rendering window.
    */
@@ -114,7 +103,7 @@ public:
   virtual Visual* GetDesiredVisual();
   virtual vtkXVisualInfo* GetDesiredVisualInfo();
   virtual int GetDesiredDepth();
-  //@}
+  ///@}
 
   /**
    * Prescribe that the window be created in a stereo-capable mode. This
@@ -124,6 +113,12 @@ public:
    */
   void SetStereoCapableWindow(vtkTypeBool capable) override;
 
+  /**
+   * Set whether this xwindow should be coverable by other windows,
+   * as opposed to always on top.
+   */
+  void SetCoverable(vtkTypeBool coverable) override;
+
   /**
    * Make this window the current OpenGL context.
    */
@@ -134,6 +129,11 @@ public:
    */
   bool IsCurrent() override;
 
+  /**
+   * Release the current context.
+   */
+  void ReleaseCurrent() override;
+
   /**
    * If called, allow MakeCurrent() to skip cache-check when called.
    * MakeCurrent() reverts to original behavior of cache-checking
@@ -162,6 +162,8 @@ public:
   void* GetGenericContext() override;
   void* GetGenericDrawable() override { return reinterpret_cast<void*>(this->WindowId); }
 
+  void* GetGenericFBConfig();
+
   /**
    * Get the current size of the screen in pixels.
    * An HDTV for example would be 1920 x 1080 pixels.
@@ -177,42 +179,56 @@ public:
   /**
    * Get this RenderWindow's X display id.
    */
+  VTK_MARSHALEXCLUDE(VTK_MARSHAL_EXCLUDE_REASON_NOT_SUPPORTED)
   Display* GetDisplayId();
 
-  //@{
+  /**
+   * Ensure RenderWindow's X display is opened
+   */
+  bool EnsureDisplay() override;
+
+  ///@{
   /**
    * Set the X display id for this RenderWindow to use to a pre-existing
    * X display id.
    */
+  VTK_MARSHALEXCLUDE(VTK_MARSHAL_EXCLUDE_REASON_NOT_SUPPORTED)
   void SetDisplayId(Display*);
+  VTK_MARSHALEXCLUDE(VTK_MARSHAL_EXCLUDE_REASON_NOT_SUPPORTED)
   void SetDisplayId(void*) override;
-  //@}
+  ///@}
 
   /**
    * Get this RenderWindow's parent X window id.
    */
+  VTK_MARSHALEXCLUDE(VTK_MARSHAL_EXCLUDE_REASON_NOT_SUPPORTED)
   Window GetParentId();
 
-  //@{
+  ///@{
   /**
    * Sets the parent of the window that WILL BE created.
    */
+  VTK_MARSHALEXCLUDE(VTK_MARSHAL_EXCLUDE_REASON_NOT_SUPPORTED)
   void SetParentId(Window);
+  VTK_MARSHALEXCLUDE(VTK_MARSHAL_EXCLUDE_REASON_NOT_SUPPORTED)
   void SetParentId(void*) override;
-  //@}
+  ///@}
 
   /**
    * Get this RenderWindow's X window id.
    */
+  VTK_MARSHALEXCLUDE(VTK_MARSHAL_EXCLUDE_REASON_NOT_SUPPORTED)
   Window GetWindowId();
 
-  //@{
+  ///@{
   /**
    * Set this RenderWindow's X window id to a pre-existing window.
    */
+  VTK_MARSHALEXCLUDE(VTK_MARSHAL_EXCLUDE_REASON_NOT_SUPPORTED)
   void SetWindowId(Window);
+  VTK_MARSHALEXCLUDE(VTK_MARSHAL_EXCLUDE_REASON_NOT_SUPPORTED)
   void SetWindowId(void*) override;
-  //@}
+  ///@}
 
   /**
    * Specify the X window id to use if a WindowRemap is done.
@@ -231,6 +247,12 @@ public:
    */
   void SetWindowName(const char*) override;
 
+  /**
+   * For window manager that supports it, set the icon displayed
+   * in the taskbar and the title bar.
+   */
+  void SetIcon(vtkImageData* img) override;
+
   /**
    * Initialize the render window from the information associated
    * with the currently activated OpenGL context.
@@ -242,7 +264,7 @@ public:
    */
   bool GetPlatformSupportsRenderWindowSharing() override { return true; }
 
-  //@{
+  ///@{
   /**
    * Set the position (x and y) of the rendering window in
    * screen coordinates (in pixels). This resizes the operating
@@ -250,16 +272,16 @@ public:
    */
   void SetPosition(int x, int y) override;
   void SetPosition(int a[2]) override { this->SetPosition(a[0], a[1]); }
-  //@}
+  ///@}
 
-  //@{
+  ///@{
   /**
    * Hide or Show the mouse cursor, it is nice to be able to hide the
    * default cursor if you want VTK to display a 3D cursor instead.
    */
   void HideCursor() override;
   void ShowCursor() override;
-  //@}
+  ///@}
 
   /**
    * Change the shape of the cursor
@@ -294,7 +316,7 @@ public:
    */
   void Render() override;
 
-  //@{
+  ///@{
   /**
    * Ability to push and pop this window's context
    * as the current context. The idea being to
@@ -304,7 +326,7 @@ public:
    */
   void PushContext() override;
   void PopContext() override;
-  //@}
+  ///@}
 
   /**
    * Set the number of vertical syncs required between frames.
@@ -349,6 +371,7 @@ protected:
   Cursor XCSizeSE;
   Cursor XCSizeSW;
   Cursor XCHand;
+  Cursor XCCustom;
 
   void CreateAWindow() override;
   void DestroyWindow() override;
@@ -357,6 +380,12 @@ protected:
 private:
   vtkXOpenGLRenderWindow(const vtkXOpenGLRenderWindow&) = delete;
   void operator=(const vtkXOpenGLRenderWindow&) = delete;
+
+  /**
+   * Ensure GLX symbols are loaded. Returns false when GLX is unavailable.
+   */
+  bool EnsureGLX();
 };
 
+VTK_ABI_NAMESPACE_END
 #endif
