@@ -64,6 +64,8 @@ from .vtkRenderingOpenVR import *
 from .vtkRenderingMatplotlib import *
 from .vtkRenderingLOD import *
 from .vtkRenderingImage import *
+from .vtkChartsCore import *
+from .vtkRenderingGridAxes import *
 from .vtkIOMovie import *
 from .vtkIOVideo import *
 from .vtkIOFFMPEG import *
@@ -104,6 +106,7 @@ from .vtkIOMPIParallel import *
 from .vtkIOMPIImage import *
 from .vtkIOMINC import *
 from .vtkIOLAS import *
+from .vtkIOLANLX3D import *
 from .vtkIOImport import *
 from .vtkIOIOSS import *
 from .vtkIOHDF import *
@@ -124,6 +127,7 @@ from .vtkIOChemistry import *
 from .vtkIOCesium3DTiles import *
 from .vtkIOCONVERGECFD import *
 from .vtkIOCGNSReader import *
+from .vtkIOAvmesh import *
 from .vtkIOAsynchronous import *
 from .vtkIOAlembic import *
 from .vtkIOAMR import *
@@ -174,7 +178,6 @@ from .vtkFiltersParallelMPI import *
 from .vtkDomainsChemistryOpenGL2 import *
 from .vtkCommonPython import *
 from .vtkCommonArchive import *
-from .vtkChartsCore import *
 from .vtkCommonColor import *
 from .vtkImagingSources import *
 from .vtkInfovisCore import *
